In Which We Discuss Whether Taylor's Or Beyonce's Lyrics Are Better Break-Up Material | People | The Debrief
Description: While Taylor is good for break-ups, there’s a Beyonce lyric for literally every occasion.
Keywords: taylor swift breakup letter

Stevie Martin | Staff Writer | Tuesday, 25 November 2014

# In Which We Discuss Whether Taylor's Or Beyonce's Lyrics Are Better Break-Up Material

The Debrief: While Taylor is good for break-ups, there’s a Beyonce lyric for literally every occasion

### Share This

Some absolute genius of a woman has written a break-up letter that comprises entirely of Taylor Swift lyrics because, let’s face it, pretty much every single Taylor Swift song is about a break-up. Apart from... nope. I’ve got nothing.

Anyway, while T-Swift can provide excellent firepower for a particular kind of breakup letter – what if you want to go a bit more ballsy? Like, Beyonce ballsy? Wonder no more because we’ve channelled Queen Bey into the perfect method for getting rid of a cheatin’ man. Or woman. Or someone who hasn’t cheated at all, but you’re just not feeling it anymore.

READ MORE: Style And Design Tips From Taylor Swift's New Video For Blank Space

Hey babe,

There was a time I thought that you did everything right. No lies, no wrong. Boy I, must’ve been out of my mind, so when I think of the time that I almost loved you, you showed your self and I saw the real you. If I were a boy, I think I could understand how it feels to love a girl – I swear I’d be a better man. I wanted you bad – I'm so through with that, because honestly, you turned out to be the best thing I never had. I’m taking back the things I got from you, on top of you not calling me back – you see I bet you think it’s all on track, but what about my body? You would rather go and party.

I give you everything you want everything you need. Even your friends say I’m a good woman, all I need to know is why? Why don’t you love me? I got beauty, I got class, I got style, and I got ass and you don’t even care to care. Bet it sucks to be you right now – don’t you ever for a second get to thinking you're irreplaceable; what goes around comes back around.

Baby I won’t shed a tear for you, I won’t lose a wink of sleep, because the truth of the matter is replacing you is so easy

[insert your name here]

Sure, it makes you sound a bit all over the place (while Tay mainly does nostalgic, hurt songs – Bey goes all out raging, as well as hurt, and secure as well as insecure), but what great break-up letter doesn’t? I remember once running down the road in no shoes after an ex yelling, ‘I’M NOT MAD, COME BACK HERE.’ Breaking up is a paradox.

And Beyonce’s lyrics don’t just go well with relationships, oh no – while Taylor tends to focus on matters of the (broken) heart, Beyonce’s back catalogue works pretty well in most scenarios. Look, there’s a Beyonce for all occasions:

A Beyonce lyric for...

Quitting your job email: Fuck you, pay me.

Drunk birthday speech: This goes out to all my girls that’s in the club rocking the latest! Who will buy it for themselves and get more money later. I think I need a barber.

Letter to your best mate: And if you wasn’t for you, and if I didn’t know you, and if you never reached me, and if you didn’t teach me, I wouldn’t be, who I am right now.

Discussing your monthly cycle with your GP: I been on, I been on, I been on – tell me who gone take me off, take me off, take me off, take me off, ’cause I been on

Speaking with changing room attendants: Stop, I ain’t ready yet. Wait, let me fix my hair. I think I’m ready

Giving sex advice from the 1950s: Ladies look here, when you been with your man for a long time, every now and then you gotta go back in the closet and pull out that freakum dress.

Like this? You might also be interested in...

Sold Out Moisturiser Is The Hero Of Beyonce's 7/11 Video

Beyonce Behaves A Bit Weirdly, The Internet Gets Even Weirder

A Few Signs We Might Be Drifting Apart From Beyonce

Follow Stevie on Twitter: @5tevieM

Tags: Beyonce, Relationships, Taylor Swift

At work? With your gran?

You might want to think about the fact you're about to read something that wouldn't exactly get a PG rating

### Share This

### Comments

The Debrief chat powered by DISQUS Read more

#### Disqus

Disqus allows you to post comments on our site. You can only post comments if you register with Disqus and your registration data will be handled in accordance with their privacy policy.

Disqus will use your registration data (email) to send you additional information. Details of how you can opt out are contained in the verification email which you will be sent after you sign up

Please read the Disqus terms of service

Loading...

comments powered by Disqus

## Need a change of scene?

### Sex

#### Out Of Lube? Try These Six Alternatives You'll Have Around The House

### Life

#### Why Are So Many Of Us Living Below The Poverty Line?

### Life

#### Dirty Pants And Used Condoms: The Reality Of Being A Cleaner For 20-Somethings

## Sign UpNow

For exclusive news, reviews, ace competitions and discounts, sign up for our email. It'll make your inbox great. Guaranteed.

Get The Debrief

## We reckon you’ll also want to read

### Fame

#### Sold-Out Moisturiser Is The Urban Legend Of Beyoncé’s New-Ish Video

### Fame

#### A Few Signs That We Might Be Drifting Apart From Beyonce

### Fame

#### Beyoncé's Fans Are Conservative And Sam Smith's Love Carbs

### Fame

#### Beyonce Behaves A Bit Weirdly. The Internet Gets Weirder

### Life

#### Taylor Swift Made An Interesting Point About Independence In A Relationship

### Fame

#### Beyoncé's Fringe Is Totally Fine By Us - So Get Over It, Haters

## Join Us Elsewhere

## Join Us OnPinterest